# Bestatic

![Bestatic Logo](https://raw.githubusercontent.com/tatsatb/bestatic/main/favicon_package/Bestatic_Logo_svg.svg)

## Detailed documentation is available on the [official website](https://www.bestaticpy.com/).

Bestatic is a simple but powerful static-site generator that you can install graphically without worrying about dependencies. It can simply turn your text files into fully functional websites and blogs.

It is really minimal yet feature-rich. Like every other static-site generator,
it can generate a complete website by processing a bunch of markdown files. As a result, it eliminates the need for server-side programming, databases, and constant security updates. The site that _Bestatic_ generates can be served from any web server or host (or even from Git-based platforms, for completely free). 

Some salient features of _Bestatic_ that are probably worth highlighting:

-  **Blog-aware**. You can easily create your blog/news page along with your website. Customizable list pages for blog posts, reverse chronological order of posts, tags, comments (using Giscus or Disqus), fully customizable URL structures, RSS feeds - All standard good stuff are already included.


-  **Feature-rich**. Want LaTeX support? Syntax highlighting for code? Powerful search functionality? Auto-reloading server? Configurable navigation? Custom taxonomies (categories, multiple authors, etc.)? We have all these things built-in. Oh yes, unlike many other static-site generators, our multi-column content layout work out of the box.  


- **Flexible and extensible**. Want to configure things in your way? Use simple yaml files. Want to use command line? Use our CLI options. Want to theme in your own way? Use standard Jinja2 templating to design freely. Want to use different markdown plugins or maybe your own custom shortcode? All of these things can de done pretty easily, without any prior knowledge. 


-  **Scalable**. Bestatic ultimately builds a bunch of static files. So, no need for database management, server maintenance, or constant security updates. A hassle-free way to manage large-scale websites.

-  **Free and open-source**. Of course, Bestatic is free and open-source, licensed under GNU GPL-3.0. This will remain free and open-source forever.


-  **Simple**. Making things simple for you is our goal. Be it via graphical installation, OS compatibility, dedicated quickstart, or in-depth documentation: We just want to make your Bestatic journey easy and enjoyable for the beginning!


## Getting started

Want to try Bestatic? Download and install it from the [release page](https://github.com/tatsatb/bestatic/releases/latest), or [Snap store](https://snapcraft.io/bestatic), or [Flathub](https://flathub.org/apps/com.bestaticpy.bestatic), or [PyPI](https://pypi.org/project/Bestatic/). 

Detailed installation instructions, quickstart guide, and user manual are available on our [official documentation](https://www.bestaticpy.com/docs/). 

  

